==> rubygem-rubytree-0.9.7.txz: usr/local/lib/ruby/gems/2.2/gems/rubytree-0.9.7/test/run_test.rb <==
#!/usr/bin/env ruby
#
# run_test.rb:: Run all the tests from the Ruby command line.
#
# Author:  Anupam Sengupta
# Time-stamp: <2014-01-03 21:15:37 anupam>
# Copyright (C) 2014 Anupam Sengupta <anupamsg@gmail.com>
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
# - Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# - Redistributions in binary form must reproduce the above copyright notice, this
#   list of conditions and the following disclaimer in the documentation and/or
#   other materials provided with the distribution.
#
# - Neither the name of the organization nor the names of its contributors may
#   be used to endorse or promote products derived from this software without
#   specific prior written permission.
#
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

base_dir = File.expand_path(File.join(File.dirname(__FILE__), ".."))
lib_dir  = File.join(base_dir, "lib")
test_dir = File.join(base_dir, "test")

$LOAD_PATH.unshift(lib_dir)

if ENV["COVERAGE"]
  begin
    require 'simplecov'
    require 'coveralls'

    SimpleCov.formatter = Coveralls::SimpleCov::Formatter

    SimpleCov.start do
      add_filter '/test/'
      add_group 'Core Classes', '/lib/.*tree.rb'
      add_group 'Internal Utilities', '/lib/tree/utils/.*.rb'
    end
  rescue LoadError => e
    puts "Could not load simplecov; continuing without code coverage"
  end
end

require 'test/unit'

exit Test::Unit::AutoRunner.run(true, test_dir)

==> rubygem-rubytree-1.0.0.txz: usr/local/lib/ruby/gems/2.7/gems/rubytree-1.0.0/test/run_test.rb <==
#!/usr/bin/env ruby
#
# run_test.rb:: Run all the tests from the Ruby command line.
#
# Author:  Anupam Sengupta
# Time-stamp: <2014-01-03 21:15:37 anupam>
# Copyright (C) 2014 Anupam Sengupta <anupamsg@gmail.com>
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
# - Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
# - Redistributions in binary form must reproduce the above copyright notice, this
#   list of conditions and the following disclaimer in the documentation and/or
#   other materials provided with the distribution.
#
# - Neither the name of the organization nor the names of its contributors may
#   be used to endorse or promote products derived from this software without
#   specific prior written permission.
#
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

base_dir = File.expand_path(File.join(File.dirname(__FILE__), '..'))
lib_dir  = File.join(base_dir, 'lib')
test_dir = File.join(base_dir, 'test')

$LOAD_PATH.unshift(lib_dir)

if ENV['COVERAGE']
  begin
    require 'simplecov'
    require 'coveralls'

    SimpleCov.formatter = Coveralls::SimpleCov::Formatter

    SimpleCov.start do
      add_filter '/test/'
      add_group 'Core Classes', '/lib/.*tree.rb'
      add_group 'Internal Utilities', '/lib/tree/utils/.*.rb'
    end
  rescue LoadError => e
    puts 'Could not load simplecov; continuing without code coverage' + e.cause
  end
end

require 'test/unit'

Test::Unit::AutoRunner.run(true, test_dir)
